@@ -19,6 +19,7 @@ import platform
 import zipfile
 import signal
 import contextlib
+from configparser import RawConfigParser
 
 from botocore.compat import six
 #import botocore.compat
@@ -36,7 +37,6 @@ StringIO = six.StringIO
 BytesIO = six.BytesIO
 urlopen = six.moves.urllib.request.urlopen
 binary_type = six.binary_type
-RawConfigParser = six.moves.configparser.RawConfigParser
 
 
 # Most, but not all, python installations will have zlib. This is required to
@@ -77,7 +77,7 @@ class NonTranslatedStdout(object):
 
     It is deliberately set to binary mode so that `\r` does not get added to
     the line ending. This can be useful when printing commands where a
-    windows style line ending would casuse errors.
+    windows style line ending would cause errors.
     """
 
     def __enter__(self):
@@ -215,6 +215,13 @@ def get_stderr_text_writer():
     return _get_text_writer(sys.stderr, errors="replace")
 
 
+def get_stderr_encoding():
+    encoding = getattr(sys.__stderr__, 'encoding', None)
+    if encoding is None:
+        encoding = 'utf-8'
+    return encoding
+
+
 def compat_input(prompt):
     """
     Cygwin's pty's are based on pipes. Therefore, when it interacts with a Win32
